@@ -26,6 +26,7 @@ from .grid_search import GridSearch
 from .models import ModelsLoader
 from .preprocessing.egonet import EgonetFeatures
 from .preprocessing.rwalk import RwalkFeatures
+from .preprocessing.spectrum import SpectrumFeatures
 from .preprocessing.transactions_to_graph import Transactions2Graph
 from .voting import VotingClassifier
 
@@ -218,7 +219,7 @@ class GraphomalyEstimator(BaseEstimator):
                 module
             * to_feature_args: dictionary
                 Available key values
-                * algorithms: list, `'egonet'`, `'rwalk'`
+                * algorithms: list, `'egonet'`, `'rwalk'`, `'spectrum'`
                 * algorithms_args: dictionary, '`ctor_args'` and `'fit_args'`
                     *ctor_args: dictionary
                         Represents arguments passed to the algorithm's constructor.
@@ -241,13 +242,15 @@ class GraphomalyEstimator(BaseEstimator):
 
         # if type == "transactions_to_features":
         if type == "graph_to_features":
-            y = self._preprocess_labels(X, y, type)
+            if y is not None:
+                y = self._preprocess_labels(X, y, type)
             X = self._process_graph_to_features(X, **kwargs)
         elif type == "transactions_to_graph_to_features":
             to_graph_args = kwargs["to_graph_args"]
             to_features_args = kwargs["to_features_args"]
 
-            y = self._preprocess_labels(X, y, type)
+            if y is not None:
+                y = self._preprocess_labels(X, y, type)
             t2g = Transactions2Graph()
             G = t2g.fit_transform(X, **to_graph_args)
 
@@ -296,6 +299,10 @@ class GraphomalyEstimator(BaseEstimator):
                 rwalk = RwalkFeatures(**ctor_args)
                 features = rwalk.fit_transform(G, **fit_args)
                 features_names_in = rwalk.feature_names_in_
+            elif algo == "spectrum":
+                spectrum = SpectrumFeatures(**ctor_args)
+                spectrum.fit_transform(G, **fit_args)
+                features_names_in = spectrum.feature_names_in_
             all_features.append(features)
             self.feature_names_in_.append(features_names_in)
 
