@@ -137,7 +137,7 @@ class GridSearch:
         best_ba = 0
         p = Path(self.datadir)
         experiments = list(p.glob(f"{self.clf_name}-*"))
-        for experiment in experiments:
+        for i, experiment in enumerate(experiments):
             if os.path.isdir(experiment):  # tf
                 clf = load_model(experiment)
                 with open(str(experiment) + "/metrics", "rb") as fp:
@@ -145,7 +145,7 @@ class GridSearch:
             else:
                 with open(experiment, "rb") as fp:
                     [clf, ba, tpr, tnr, duration, tn, fp, fn, tp] = pickle.load(fp)
-            if ba > best_ba:
+            if ba > best_ba or i == 0:
                 best_ba = ba
                 best_tpr = tpr
                 best_tnr = tnr
